<?php

require_once("../../class/class.conectar.php");
require_once("../../class/class.usuaprueba.php");
require_once("../../class/class.usutrab.php");
require_once("../../class/class.personal.php");
require_once("../../class/class.horareprog.php");
require_once("../../class/class.horaeje.php");
require_once("../../class/class.descmed.php");
require_once("../../class/class.faltas.php");

$Objcon = new Conectar();
$conex = $Objcon->con();

if(isset($_GET['repro'])){
$val = $_GET['repro'];
//echo $val."<br>";
if($val==1){
$anno= $_GET['anno'];
$mm= $_GET['mes'];
$idj= $_GET['idj'];
$ids= $_GET['ids'];
$idtp= $_GET['idtp'];
$ugid= $_GET['ugid'];
}
}
echo "<input type='hidden' id='idj' name='idj' value='".$idj."'>";
echo "<input type='hidden' id='ids' name='ids' value='".$ids."'>";
echo "<input type='hidden' id='anno' name='anno' value='".$anno."'>";
echo "<input type='hidden' id='mes' name='mes' value='".$mm."'>";
echo "<input type='hidden' id='idtp' name='idtp' value='".$idtp."'>";
echo "<input type='hidden' id='ugid' name='ugid' value='".$ugid."'>";

//pregunta si esta validado

$Objua_valeje1 = new UsuarioAprueba(); $Objua_valeje2 = new UsuarioAprueba();
$res_valeje1 = array(); $res_valeje2 = array();
$res_valeje1 = $Objua_valeje1->ask_validado($conex,$anno,$mm,$ids,$idj,0,2);
$res_valeje2 = $Objua_valeje2->ask_validado($conex,$anno,$mm,$ids,$idj,0,3);

if(count($res_valeje1)> 0 && count($res_valeje2)>0){
	$validado = 0;
}else{
	$validado = 1;
}

$Objua_valeje3 = new UsuarioAprueba();
$res_valeje3 = array();
$res_valeje3 = $Objua_valeje3->ask_validado($conex,$anno,$mm,$ids,$idj,$idtp,4);
if(count($res_valeje3)> 0){
	$validado2 = 1;
}else{
	$validado2 = 0;
}
?>

<br>
<table align='center' width='940'><tr><td class='LlenarTablaGarea' align='center'>AUSENTISMO LABORAL DEL PERSONAL ASISTENCIAL</td></tr><tr><td align='center' class ='FacetDataTextC'><input type='button' value='Grabar' onClick='grabarfaltas()' <?php if($validado==1 or $validado2==1){ echo " disabled ";}?>><input type='button' value='Imprimir' onCLick='informafaltaspdf()'
><input type='button' value='Validar' onCLick='validarfaltas()'<?php if($validado2==1 or $validado==1){ echo " disabled ";}?>></td></tr></table>
<table align='center'>
<tr><td class='LlenarTablaGarea' width='30'>CANT</td><td align='center' class='LlenarTablaGarea' width='250'>NOMBRE DEL PERSONAL</td><td align='center' width='110' class='LlenarTablaGarea'>FECHA PROGRAMADO</td><td align='center' width='70' class='LlenarTablaGarea'>TURNO</td><td align='center' width='150' class='LlenarTablaGarea'>TIPO DE HORA</td></tr>

<?php
$Objrp = new HoraReprogramacion();
$res_rp = array();
$res_rp = $Objrp->ask_reprog_mes($conex,$anno,$mm,$idj,$ids,$idtp);

if(count($res_rp)>0){

//pregunta por el personal
$Objprp = new UsuarioTrabaja();
$res_prp = array();
$res_prp = $Objprp->listar_per_trab_per_serv($conex,$anno,$mm,$idj,$ids,$idtp);
//print_r($res_prp);
$aa=0;
$bb=0;
$pp=0;
$ii=1;
for($i=0;$i<count($res_prp);$i++){
	$codper=$res_prp[$i]['cod'];
	$codprog=$res_prp[$i]['codigo'];
	$nombre=$res_prp[$i]['nombre'];

//pregunta por la reprogramacion
$Objhrsreprog = new HoraReprogramacion();
$res_hrsreprog = array();
$res_hrsreprog = $Objhrsreprog->ask_reprog_mes_per($conex,$anno,$mm,$idj,$ids,$idtp,$codper);

$Objhrseje = new HoraEjecucion();
$res_hrseje = array();
$res_hrseje = $Objhrseje->ask_hrseje_mes_per($conex,$anno,$mm,$idj,$ids,$idtp,$codper);

if(count($res_hrsreprog)>0){

	//pregunta por la cantidad de turnos programados del personal
		$Obj_hrsrcontar = new HoraReprogramacion();
		$cantp = $Obj_hrsrcontar->sum_turnos_reprogramados_per($conex,$anno,$mm,$idj,$ids,$idtp,$codper);

//pregunta por la cantidad de turnos reprogramados del personal
		$Obj_hrsecontar = new HoraEjecucion();
		$cantpr = $Obj_hrsecontar->sum_turnos_ejecutados_per($conex,$anno,$mm,$idj,$ids,$idtp,$codper);

		$cantp=0;
		$cantpr=0;
		$nmax=0;

		if($cantp>$cantpr){
		$nmax=$cantp;
		}else{
		$nmax=$cantpr;
		}

		echo "<tr><td align='center' class ='FacetDataTextC'>".$ii."</td><td class ='FacetDataTextC'>".$nombre."</td>";

//busca codigo del personal y el servicio
		$Objso = new UsuarioTrabaja();
		$res_so = array();
		$res_so = $Objso->buscar_per_trab_serv($conex,$anno,$mm,$idj,$ids,$idtp,$codper);

		if(count($res_so)>0){
		for($j=0;$j<count($res_so);$j++){
		$idso = $rowask[$j]['idsa'];
		}}

//PERSONAL QUE AUN NO ESTA LISTA EN REPRO
//$sqlsaverepro ="select * from tb_reprohrs where uap_anno='$anno' and ug_id='$codper' and uap_mes='$mes' and s_id='$idso' and rh_idserva='$ids' and j_id='$idj' and tp_id='$idtp'";
//$resultsaverepro = mysql_query($sqlsaverepro);
//echo $sqlsaverepro."<br>";

//if(mysql_num_rows($resultsaverepro)==0){
//echo $sqlrepro."<br>";
//turnos programados
		$cadenaprog ="<table>";
		$tipohr1="<table>";

		$cadena1="";
		$cadena2="";
		$cadena3="";
		$cadena4="";
		$cadena5="";
		$cadena6="";
		$cadena7="";


					for($p=0;$p<count($res_hrsreprog);$p++){

					$fechap = $anno."-".$mm."-".$res_hrsreprog[$p]['dia'];

					//prepara consulta de descanso medico por persona y fecha
					$Objdm = new DescansoMedico();
					$res_askdm = array();
					$res_askdm = $Objdm->consultar_descmed_fecha($conex,$codper,$fechap);


									//consulta si no tiene descanso medico
									if(count($res_askdm)==0){
									$cadenaprog= $cadenaprog."<tr><td align='center' width='100' class ='FacetDataTextC' height='22'>".$res_hrsreprog[$p]['fechap']."</td><td width='40' align='center' class ='FacetDataTextC'>".$res_hrsreprog[$p]['turnop']."</td></tr>";
									$cadena1 = $cadena1."<input type='hidden' id='idper[".$aa."]' name='idper[".$aa."]' value='".$codper."'>";
									$cadena2 = $cadena2."<input type='hidden' id='dia[".$aa."]' name='dia[".$aa."]' value='".$res_hrsreprog[$p]['dia']."'>";
									$cadena3 = $cadena3."<input type='hidden' id='utcod[".$aa."]' name='utcod[".$aa."]' value='".$res_hrsreprog[$p]['codprog']."'>";
									$cadena4 = $cadena4."<input type='hidden' id='idh[".$aa."]' name='idh[".$aa."]' value='".$res_hrsreprog[$p]['idhora']."'>";
									$cadena5 = $cadena5."<input type='hidden' id='idga[".$aa."]' name='idga[".$aa."]' value='".$res_hrsreprog[$p]['garea']."'>";
									$cadena6 = $cadena6."<input type='hidden' id='ida[".$aa."]' name='ida[".$aa."]' value='".$res_hrsreprog[$p]['area']."'>";


													if(isset($res_hrsreprog[$p]['tipohora'])){
														if($res_hrsreprog[$p]['tipohora']==0){
														$tipohr1 = $tipohr1."<tr><td align='center' class ='FacetDataTextC' height='22'>HORA ORDINARIA</td><td><input type='checkbox' name='lista[".$aa."]' id='lista[".$aa."]'";
														//falta falta falta
														$Obj_f_ho = new Faltas();
														$res_f_ho = array();
														$res_f_ho = $Obj_f_ho->consultar_regfaltas_per($conex,$anno,$mm,$res_hrsreprog[$p]['dia'],$codper,$idj,$ids,$idtp,$res_hrsreprog[$p]['garea'],$res_hrsreprog[$p]['area'],$res_hrsreprog[$p]['idhora'],0);
														if(count($res_f_ho)>0){
														$tipohr1 = $tipohr1." checked"; }
														$tipohr1 = $tipohr1."></td></tr>";
														$cadena7 = $cadena7."<input type='hidden' id='idth[".$aa."]' name='idth[".$aa."]' value='0'>";
														}else{
														$tipohr1 = $tipohr1."<tr><td align='center' class ='FacetDataTextC' height='22'>HORA EXTRA</td><td><input type='checkbox'  name='lista[".$aa."]' id='lista[".$aa."]'";

														$Obj_f_he = new Faltas();
														$res_f_he = array();
														$res_f_he = $Obj_f_he->consultar_regfaltas_per($conex,$anno,$mm,$res_hrsreprog[$p]['dia'],$codper,$idj,$ids,$idtp,$res_hrsreprog[$p]['garea'],$res_hrsreprog[$p]['area'],$res_hrsreprog[$p]['idhora'],1);
													  if(count($res_f_he)>0){
														$tipohr1 = $tipohr1." checked";
														}
														$tipohr1 = $tipohr1."></td></tr>";
														$cadena7 = $cadena7."<input type='hidden' id='idth[".$aa."]' name='idth[".$aa."]' value='1'>";
														}
													}

									$aa = $aa +1;
									}

				 }
				 $tipohr1 =$tipohr1."</table>";
				 $cadenaprog =$cadenaprog."</table>";

					//imprime cambios
					echo "<td colspan='2' align='center' class ='FacetDataTextC'>".$cadenaprog."</td><td width='150' align='center'  class ='FacetDataTextC'>".$tipohr1."</td></tr>";

					$ii = $ii + 1;

					//echo "numero".$aa;

					echo $cadena1.$cadena2.$cadena3.$cadena4.$cadena5.$cadena6.$cadena7;
			}

		}
		echo "<input type='hidden' id='conta' name='conta' value='".$aa."'>";
}
?>
</table>
